@@ -16,11 +16,11 @@ from datetime import datetime
 from typing import Any, Dict, List
 
 from .literals import (
-    EndpointState,
-    FailureReason,
-    JobRunState,
-    PersistentAppUI,
-    VirtualClusterState,
+    EndpointStateType,
+    FailureReasonType,
+    JobRunStateType,
+    PersistentAppUIType,
+    VirtualClusterStateType,
 )
 
 if sys.version_info >= (3, 8):
@@ -231,7 +231,7 @@ EndpointTypeDef = TypedDict(
         "arn": str,
         "virtualClusterId": str,
         "type": str,
-        "state": EndpointState,
+        "state": EndpointStateType,
         "releaseLabel": str,
         "executionRoleArn": str,
         "certificateArn": str,
@@ -260,7 +260,7 @@ JobRunTypeDef = TypedDict(
         "name": str,
         "virtualClusterId": str,
         "arn": str,
-        "state": JobRunState,
+        "state": JobRunStateType,
         "clientToken": str,
         "executionRoleArn": str,
         "releaseLabel": str,
@@ -270,7 +270,7 @@ JobRunTypeDef = TypedDict(
         "createdBy": str,
         "finishedAt": datetime,
         "stateDetails": str,
-        "failureReason": FailureReason,
+        "failureReason": FailureReasonType,
         "tags": Dict[str, str],
     },
     total=False,
@@ -314,7 +314,7 @@ ListVirtualClustersResponseTypeDef = TypedDict(
 MonitoringConfigurationTypeDef = TypedDict(
     "MonitoringConfigurationTypeDef",
     {
-        "persistentAppUI": PersistentAppUI,
+        "persistentAppUI": PersistentAppUIType,
         "cloudWatchMonitoringConfiguration": "CloudWatchMonitoringConfigurationTypeDef",
         "s3MonitoringConfiguration": "S3MonitoringConfigurationTypeDef",
     },
@@ -377,7 +377,7 @@ VirtualClusterTypeDef = TypedDict(
         "id": str,
         "name": str,
         "arn": str,
-        "state": VirtualClusterState,
+        "state": VirtualClusterStateType,
         "containerProvider": "ContainerProviderTypeDef",
         "createdAt": datetime,
         "tags": Dict[str, str],
